@@ -19,7 +19,7 @@
 # You should have received a copy of the GNU General Public License
 # along with Project Hamster.  If not, see <http://www.gnu.org/licenses/>.
 
-
+import logging
 import datetime as dt
 import os.path
 
@@ -126,9 +126,9 @@ class PanelButton(gtk.ToggleButton):
                 label = "%s\n%s" % (self.activity, self.duration)
             else:
                 label = "%s %s" % (self.activity, self.duration)
-
-        label = '<span gravity="south">%s</span>' % stuff.escape_pango(label)
-        self.label.set_markup("") #clear - seems to fix the warning
+        
+        label = stuff.escape_pango(label)
+        label = '<span gravity=\"south\">' + label + '</span>'
         self.label.set_markup(label)
 
     def get_pos(self):
@@ -248,8 +248,10 @@ class HamsterApplet(object):
             runtime.dispatcher.add_handler('active_changed', self.on_idle_changed)
 
         except dbus.DBusException, e:
-            print "can't init dbus: %s" % e
+            logging.error("Can't init dbus: %s" % e)
     
+        self.day_start = self.config.get_day_start()
+
         # Load today's data, activities and set label
         self.last_activity = None
         self.load_day()
@@ -279,6 +281,7 @@ class HamsterApplet(object):
         runtime.dispatcher.add_handler('gconf_notify_on_idle_changed', self.on_notify_on_idle_changed)
         self.notify_on_idle = self.config.get_notify_on_idle()
         
+        runtime.dispatcher.add_handler('gconf_on_day_start_changed', self.on_day_start_changed)
         
         # init nagging timeout
         if PYNOTIFY:
@@ -296,6 +299,7 @@ class HamsterApplet(object):
         self.treeview.append_column(gtk.TreeViewColumn("Time",
                                                        gtk.CellRendererText(),
                                                        text=2))
+
         self.treeview.append_column(stuff.ActivityColumn(name=1,
                                                          description=5,
                                                          category=6))
@@ -303,7 +307,6 @@ class HamsterApplet(object):
         duration_cell = gtk.CellRendererText()
         duration_cell.set_property("xalign", 1)
         timeColumn = gtk.TreeViewColumn(_("Duration"), duration_cell, text=3)
-        
         self.treeview.append_column(timeColumn)
 
         edit_cell = gtk.CellRendererPixbuf()
@@ -524,7 +527,8 @@ class HamsterApplet(object):
         """sets up today's tree and fills it with records
            returns information about last activity"""
         #today is 5.5 hours ago because our midnight shift happens 5:30am
-        today = (dt.datetime.now() - dt.timedelta(hours=5, minutes=30)).date()
+        today = (dt.datetime.now() - dt.timedelta(hours = self.day_start.hour,
+                                                  minutes = self.day_start.minute)).date()
 
         self.last_activity = runtime.storage.get_last_activity()
 
@@ -532,24 +536,24 @@ class HamsterApplet(object):
         fact_store.clear()
         facts = runtime.storage.get_facts(today)
         
-        if len(facts) > 10:
-            self._gui.get_object("todays_scroll").set_size_request(-1, 250)
-            self._gui.get_object("todays_scroll").set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_ALWAYS)
-        else:
-            self._gui.get_object("todays_scroll").set_size_request(-1, -1)
-            self._gui.get_object("todays_scroll").set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_NEVER)
-            
         by_category = {}
+        
         for fact in facts:
             duration = 24 * 60 * fact["delta"].days + fact["delta"].seconds / 60
             by_category[fact['category']] = \
                           by_category.setdefault(fact['category'], 0) + duration
 
+            if fact["end_time"]:
+                fact_time = "%s - %s " % (fact["start_time"].strftime("%H:%M"),
+                                       fact["end_time"].strftime("%H:%M"))
+            else:
+                fact_time = fact["start_time"].strftime("%H:%M ")
+
             fact_store.append([fact['id'],
                                stuff.escape_pango(fact['name']), 
-                               fact["start_time"].strftime("%H:%M"), 
+                               fact_time, 
                                "%s" % stuff.format_duration(duration),
-                               fact["start_time"].strftime("%H:%M"),
+                               "",
                                stuff.escape_pango(fact["description"]),
                                stuff.escape_pango(fact["category"]),
                                fact])
@@ -811,6 +815,9 @@ class HamsterApplet(object):
             runtime.storage.touch_fact(self.last_activity,
                                        end_time = self.dbusIdleListener.getIdleFrom())
 
+    def on_day_start_changed(self, event, new_minutes):
+        self.day_start = self.config.get_day_start()
+        self.load_day()
 
     """global shortcuts"""
     def on_keybinding_activated(self, event, data):
